% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conformalize.R
\name{conformalize}
\alias{conformalize}
\title{Conformal Prediction for Regression Models}
\usage{
conformalize(
  formula = NULL,
  x = NULL,
  y = NULL,
  data = NULL,
  fit_func,
  predict_func = predict,
  split_ratio = 0.5,
  seed = NULL,
  ...
)
}
\arguments{
\item{formula}{A formula specifying the model to be fitted.}

\item{x}{A numeric matrix of predictors.}

\item{y}{A numeric vector of responses.}

\item{data}{A data frame containing the variables in the formula.}

\item{fit_func}{A function to fit the model. It should take a formula and data as arguments.}

\item{predict_func}{A function to make predictions. It should take a fitted model and new data as arguments.}

\item{split_ratio}{The proportion of data to use for training. Default is 0.5.}

\item{seed}{An optional seed for reproducibility.}
}
\value{
A list containing the fitted model, residuals, and other relevant information.
}
\description{
This function implements conformal prediction for regression models using a split conformal approach.
}
\examples{
# Example usage with a linear model
library(MASS)
data(Boston)
set.seed(123)
fit_func <- function(formula, data) {
  lm(formula, data = data)
}
predict_func <- function(fit, newdata) {
  predict(fit, newdata)
}
conformalize(formula = medv ~ ., data = Boston, fit_func = fit_func,
predict_func = predict_func, split_ratio = 0.5, seed = 123)

}
